@@ -6,8 +6,8 @@ toolkit specific classes since it implements the core
 functionality. See the class docs for more details.
 
 """
-# Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2007, Enthought, Inc.
+# Author: Prabhu Ramachandran <prabhu@enthought.com>
+# Copyright (c) 2007-2013, Enthought, Inc.
 # License: BSD Style.
 
 
@@ -405,7 +405,8 @@ class TVTKScene(HasPrivateTraits):
         """Saves the rendered scene to a rasterized PostScript image.
         For vector graphics use the save_gl2ps method."""
         if len(file_name) != 0:
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=False)
+            w2if = tvtk.WindowToImageFilter(read_front_buffer=
+                                              not self.off_screen_rendering)
             w2if.magnification = self.magnification
             self._lift()
             w2if.input = self._renwin
@@ -417,7 +418,8 @@ class TVTKScene(HasPrivateTraits):
     def save_bmp(self, file_name):
         """Save to a BMP image file."""
         if len(file_name) != 0:
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=False)
+            w2if = tvtk.WindowToImageFilter(read_front_buffer=
+                                              not self.off_screen_rendering)
             w2if.magnification = self.magnification
             self._lift()
             w2if.input = self._renwin
@@ -429,7 +431,8 @@ class TVTKScene(HasPrivateTraits):
     def save_tiff(self, file_name):
         """Save to a TIFF image file."""
         if len(file_name) != 0:
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=False)
+            w2if = tvtk.WindowToImageFilter(read_front_buffer=
+                                              not self.off_screen_rendering)
             w2if.magnification = self.magnification
             self._lift()
             w2if.input = self._renwin
@@ -441,7 +444,8 @@ class TVTKScene(HasPrivateTraits):
     def save_png(self, file_name):
         """Save to a PNG image file."""
         if len(file_name) != 0:
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=False)
+            w2if = tvtk.WindowToImageFilter(read_front_buffer=
+                                              not self.off_screen_rendering)
             w2if.magnification = self.magnification
             self._lift()
             w2if.input = self._renwin
@@ -457,7 +461,8 @@ class TVTKScene(HasPrivateTraits):
         if len(file_name) != 0:
             if not quality and not progressive:
                 quality, progressive = self.jpeg_quality, self.jpeg_progressive
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=False)
+            w2if = tvtk.WindowToImageFilter(read_front_buffer=
+                                              not self.off_screen_rendering)
             w2if.magnification = self.magnification
             self._lift()
             w2if.input = self._renwin
